pub fn message_passing_operator() -> OperatorMetadataExpand description
Returns the canonical metadata for the bounded recursive message-passing operator.
pub fn message_passing_operator() -> OperatorMetadataReturns the canonical metadata for the bounded recursive message-passing operator.