pub struct CalibrationReport {
pub nuisance_node_ids: Vec<String>,
pub caveats: Vec<String>,
pub blocked: bool,
}Fields
nuisance_node_ids: Vec<String>caveats: Vec<String>blocked: boolTrait Implementations
Sourceimpl Clone for CalibrationReport
impl Clone for CalibrationReport
Sourcefn clone(&self) -> CalibrationReport
fn clone(&self) -> CalibrationReport
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CalibrationReport
impl Debug for CalibrationReport
Sourceimpl<'de> Deserialize<'de> for CalibrationReport
impl<'de> Deserialize<'de> for CalibrationReport
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CalibrationReport
Sourceimpl JsonSchema for CalibrationReport
impl JsonSchema for CalibrationReport
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CalibrationReport
impl PartialEq for CalibrationReport
Sourcefn eq(&self, other: &CalibrationReport) -> bool
fn eq(&self, other: &CalibrationReport) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CalibrationReport
impl Serialize for CalibrationReport
impl StructuralPartialEq for CalibrationReport