pub struct CertificateArtifact {
pub certificate_id: String,
pub certified_node_id: String,
pub satisfied_constraint_ids: Vec<ConstraintId>,
pub oracle_slice_id: Option<OracleSliceId>,
}Fields
certificate_id: Stringcertified_node_id: Stringsatisfied_constraint_ids: Vec<ConstraintId>oracle_slice_id: Option<OracleSliceId>Trait Implementations
Sourceimpl Clone for CertificateArtifact
impl Clone for CertificateArtifact
Sourcefn clone(&self) -> CertificateArtifact
fn clone(&self) -> CertificateArtifact
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CertificateArtifact
impl Debug for CertificateArtifact
Sourceimpl<'de> Deserialize<'de> for CertificateArtifact
impl<'de> Deserialize<'de> for CertificateArtifact
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for CertificateArtifact
Sourceimpl JsonSchema for CertificateArtifact
impl JsonSchema for CertificateArtifact
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for CertificateArtifact
impl PartialEq for CertificateArtifact
Sourcefn eq(&self, other: &CertificateArtifact) -> bool
fn eq(&self, other: &CertificateArtifact) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for CertificateArtifact
impl Serialize for CertificateArtifact
impl StructuralPartialEq for CertificateArtifact