pub struct ConstraintUnit {
pub constraint_id: ConstraintId,
pub kind: String,
pub variable_ids: Vec<String>,
pub operator_id: OperatorId,
}Fields
constraint_id: ConstraintIdkind: Stringvariable_ids: Vec<String>operator_id: OperatorIdTrait Implementations
Sourceimpl Clone for ConstraintUnit
impl Clone for ConstraintUnit
Sourcefn clone(&self) -> ConstraintUnit
fn clone(&self) -> ConstraintUnit
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ConstraintUnit
impl Debug for ConstraintUnit
Sourceimpl<'de> Deserialize<'de> for ConstraintUnit
impl<'de> Deserialize<'de> for ConstraintUnit
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ConstraintUnit
Sourceimpl JsonSchema for ConstraintUnit
impl JsonSchema for ConstraintUnit
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ConstraintUnit
impl PartialEq for ConstraintUnit
Sourcefn eq(&self, other: &ConstraintUnit) -> bool
fn eq(&self, other: &ConstraintUnit) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ConstraintUnit
impl Serialize for ConstraintUnit
impl StructuralPartialEq for ConstraintUnit