pub struct OperatorContract {
pub inputs: Vec<String>,
pub outputs: Vec<String>,
pub exactness: ExactnessClass,
pub convergence: ConvergenceKind,
pub stop_rule: StopRule,
pub degradation: DegradationBehavior,
}Fields
inputs: Vec<String>outputs: Vec<String>exactness: ExactnessClassconvergence: ConvergenceKindstop_rule: StopRuledegradation: DegradationBehaviorTrait Implementations
Sourceimpl Clone for OperatorContract
impl Clone for OperatorContract
Sourcefn clone(&self) -> OperatorContract
fn clone(&self) -> OperatorContract
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OperatorContract
impl Debug for OperatorContract
Sourceimpl<'de> Deserialize<'de> for OperatorContract
impl<'de> Deserialize<'de> for OperatorContract
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for OperatorContract
Sourceimpl JsonSchema for OperatorContract
impl JsonSchema for OperatorContract
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for OperatorContract
impl PartialEq for OperatorContract
Sourcefn eq(&self, other: &OperatorContract) -> bool
fn eq(&self, other: &OperatorContract) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for OperatorContract
impl Serialize for OperatorContract
impl StructuralPartialEq for OperatorContract