pub struct PerturbationWitness {
pub changed_node_ids: Vec<String>,
pub changed_constraint_ids: Vec<ConstraintId>,
pub budget_used: u32,
}Fields
changed_node_ids: Vec<String>changed_constraint_ids: Vec<ConstraintId>budget_used: u32Trait Implementations
Sourceimpl Clone for PerturbationWitness
impl Clone for PerturbationWitness
Sourcefn clone(&self) -> PerturbationWitness
fn clone(&self) -> PerturbationWitness
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for PerturbationWitness
impl Debug for PerturbationWitness
Sourceimpl<'de> Deserialize<'de> for PerturbationWitness
impl<'de> Deserialize<'de> for PerturbationWitness
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for PerturbationWitness
Sourceimpl JsonSchema for PerturbationWitness
impl JsonSchema for PerturbationWitness
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for PerturbationWitness
impl PartialEq for PerturbationWitness
Sourcefn eq(&self, other: &PerturbationWitness) -> bool
fn eq(&self, other: &PerturbationWitness) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for PerturbationWitness
impl Serialize for PerturbationWitness
impl StructuralPartialEq for PerturbationWitness