pub struct ResidualArtifact {
pub constraint_id: ConstraintId,
pub residual_micros: u64,
pub monotone_nonincreasing: bool,
}Fields
constraint_id: ConstraintIdresidual_micros: u64monotone_nonincreasing: boolTrait Implementations
Sourceimpl Clone for ResidualArtifact
impl Clone for ResidualArtifact
Sourcefn clone(&self) -> ResidualArtifact
fn clone(&self) -> ResidualArtifact
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ResidualArtifact
impl Debug for ResidualArtifact
Sourceimpl<'de> Deserialize<'de> for ResidualArtifact
impl<'de> Deserialize<'de> for ResidualArtifact
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for ResidualArtifact
Sourceimpl JsonSchema for ResidualArtifact
impl JsonSchema for ResidualArtifact
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ResidualArtifact
impl PartialEq for ResidualArtifact
Sourcefn eq(&self, other: &ResidualArtifact) -> bool
fn eq(&self, other: &ResidualArtifact) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for ResidualArtifact
impl Serialize for ResidualArtifact
impl StructuralPartialEq for ResidualArtifact